#define HAVE_X11 1
#define KCRASH_CORE_PATTERN_RAISE 1

#define kde_socklen_t socklen_t
#define KDE_INSTALL_FULL_LIBEXECDIR "/usr/libexec"
